/* Xmsgd 
 * Copyright (C) 2001 Thomas Vander Stichele <thomas@apestaart.org>
 * 
 * config.c: configuration stuff for Xmsg
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * version 0.6.0
 *
 * last changed : 27/06/2001
 */

#include "config.h"

#include <unistd.h>				/* getopt */
#include <stdio.h>				/* printf */
#include <stdlib.h>				/* malloc maybe ? */
#include <string.h>

/* debugging ? */
//#define DEBUG

/* internal prototypes */

void init_config (msg_t* msg);
void print_config_string (char *text, char *string);


void
init_config (msg_t* msg)
{
  /* Clear configuration type */
  
  msg->font_name = NULL;
  msg->icon_file = NULL;
  msg->color_name = NULL;
  msg->duration = 0.0;
  msg->line_number = 0;
}

int 
parse_config (int argc, char *argv[], msg_t* msg)
{
  char done = 0;				/* set to 1 when done parsing */
  char have_args = 0;			/* set to 1 when an argument has been given */
#ifdef DEBUG
  printf ("DEBUG: parse_config start\n");
#endif

  init_config (msg);	/* initializes msg_t type to NULL values */

#ifdef DEBUG
  printf ("DEBUG: filling in blanks\n");
#endif

  ClearMsg (msg);	/* sets everything to NULL */
  DefaultMsg (msg);
#ifdef DEBUG
  print_config (*msg);
#endif
  
  while (! done)
  {
    char option;

    option = getopt (argc, argv, "ficdl");
    if (option == -1)
    {
      /* no arguments left */
      done = 1;
    }
    else
    {
      have_args = 1;
	    switch (option)
	    {
	      case -1:
	        done = 1;
	        break;
	      case 'f':
	        copy_string (&msg->font_name, argv[optind], "font name\t");
	        break;
	      case 'i':
	        copy_string (&msg->icon_file, argv[optind], "icon file name");
	        break;
	      case 'c':
	        copy_string (&msg->color_name, argv[optind], "color name");
	        break;
	      case 'd':
	        sscanf (argv[optind], "%f", &msg->duration);
	        break;
	      case 'l':
	        sscanf (argv[optind], "%d", &msg->line_number);
	        break;
	    }
	    ++optind; /* skip config parameter */
	}
  } 
#ifdef DEBUG
  printf ("DEBUG: done parsing\n");
  print_config (*msg);
  printf ("DEBUG: parse_config end\n");
#endif
  return 1 /*have_args*/;
}

void 
print_config_string (char *text, char *string)
{
  if (string != NULL)
  {
    printf ("%s\t%s\n", text, string);
  }
}

void print_config (msg_t msg)
{
  print_config_string ("Font name", msg.font_name);
  print_config_string ("Icon file name", msg.icon_file);
  print_config_string ("Color name", msg.color_name);
  printf ("Duration\t%f\n", msg.duration);
  printf ("Line number\t%d\n", msg.line_number);
}
